import { Body, Controller, Get, Param, Put, Query } from '@nestjs/common';
import { ApiTags } from '@nestjs/swagger';
import { Public } from 'src/core/guards';
import { MODULE_NAME } from 'src/core/strings/constants/module.constants';
import { UserPrivilegeConfigurationDataOrchestrator } from '../domain/usecases/user-privilege-configuration/user-privilege-configuration-data.orchestrator';
import { UserPrivilegeConfigurationDto } from './dto/user-privilege-configuration.dto';
import { UserPrivilegeConfigurationEntity } from '../domain/entities/user-privilege-configuration.entity';
import { Pagination } from 'src/core/response';
import { FilterUserPrivilegeConfigurationDto } from './dto/filter-user-privilege-configuration.dto';
import { PaginationResponse } from 'src/core/response/domain/ok-response.interface';

@ApiTags(
  `${MODULE_NAME.USER_PRIVILEGE_CONFIGURATION.split('-').join(' ')} - data`,
)
@Controller(MODULE_NAME.USER_PRIVILEGE_CONFIGURATION)
@Public(false)
export class UserPrivilegeConfigurationController {
  constructor(
    private orchestrator: UserPrivilegeConfigurationDataOrchestrator,
  ) {}

  @Put()
  async update(
    @Body() data: UserPrivilegeConfigurationDto,
  ): Promise<UserPrivilegeConfigurationEntity> {
    return await this.orchestrator.update(data);
  }

  @Get()
  async index(
    @Query() params: FilterUserPrivilegeConfigurationDto,
  ): Promise<PaginationResponse<UserPrivilegeConfigurationEntity>> {
    return await this.orchestrator.index(params);
  }
}
