import { BaseStatusModel } from 'src/core/modules/data/model/base-status.model';
import { TABLE_NAME } from 'src/core/strings/constants/table.constants';
import { Column, Entity, JoinColumn, ManyToOne } from 'typeorm';
import { UserEntity } from '../../domain/entities/user.entity';
import { UserRole } from '../../constants';
import { UserPrivilegeModel } from 'src/modules/user-related/user-privilege/data/models/user-privilege.model';

@Entity(TABLE_NAME.USER)
export class UserModel
  extends BaseStatusModel<UserEntity>
  implements UserEntity
{
  @Column('varchar', { name: 'refresh_token', nullable: true })
  refresh_token: string;

  @Column('varchar', { name: 'name', nullable: true })
  name: string;

  @Column('varchar', { name: 'username', nullable: true })
  username: string;

  @Column('varchar', { name: 'password', nullable: true })
  password: string;

  @Column('varchar', { name: 'email', nullable: true })
  email: string;

  @Column('enum', { name: 'role', enum: UserRole, default: UserRole.STAFF })
  role: UserRole;

  @Column('varchar', { name: 'user_privilege_id', nullable: true })
  user_privilege_id: string;
  @ManyToOne(() => UserPrivilegeModel, (model) => model.users, {
    onDelete: 'CASCADE',
    onUpdate: 'CASCADE',
  })
  @JoinColumn({ name: 'user_privilege_id' })
  user_privilege: UserPrivilegeModel;
}
